==> isis-fish-4.2.0.1-sources.jar: fr/ifremer/isisfish/aspect/TraceAspect.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: TraceAspect.java 3736 2012-08-27 17:21:00Z bpoussin $
 * $HeadURL$
 * %%
 * Copyright (C) 2006 - 2011 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.aspect;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.codehaus.aspectwerkz.annotation.After;
import org.codehaus.aspectwerkz.annotation.AfterThrowing;
import org.codehaus.aspectwerkz.annotation.Aspect;
import org.codehaus.aspectwerkz.annotation.Before;
import org.codehaus.aspectwerkz.annotation.Expression;
import org.codehaus.aspectwerkz.definition.Pointcut;
import org.codehaus.aspectwerkz.joinpoint.JoinPoint;
import org.codehaus.aspectwerkz.joinpoint.MethodSignature;

import fr.ifremer.isisfish.IsisFishRuntimeException;
import fr.ifremer.isisfish.simulator.SimulationContext;
import fr.ifremer.isisfish.util.Trace;

/**
 * Permet de tracer les appels aux methodes utilisateur ainsi que l'execution
 * a ces methodes. La difference entre les deux est lors de l'utilisation du
 * cache les appels seront superieur a l'execution car certaine valeur seront
 * reutilisé dans le cache
 * 
 * Created: 25 août 06 22:19:21
 *
 * @author poussin
 * @version $Revision: 3736 $
 *
 * Last update: $Date: 2012-08-27 19:21:00 +0200 (Mon, 27 Aug 2012) $
 * by : $Author: bpoussin $
 */
@Aspect("perJVM")
public class TraceAspect {

    /** to use log facility, just put in your code: log.info("..."); */
    static private Log log = LogFactory.getLog(TraceAspect.class);

    @Expression("execution(* scripts..*(..))"
            + " || execution(* simulators..*(..))"
            + " || execution(* rules..*(..)) "
            + " || execution(* simulationplans..*(..)) "
            + " || execution(* formules..*(..))")
    Pointcut executeMethod;

    public TraceAspect() {
    }

    /**
     * Return trace object from context.
     * 
     * @return trace object from context
     */
    protected Trace getTrace() {
        SimulationContext context = SimulationContext.get();
        Trace result = context.getTrace();
        return result;
    }

    @Before("executeMethod")
    public void traceBeforeExecute(JoinPoint jp) {
        getTrace().traceBefore();
    }

    @AfterThrowing(type = "java.lang.Exception", pointcut = "executeMethod")
    public void traceAfterThrowingExecute(JoinPoint jp) {
        // si une exeption est leve, il faut faire la meme chose
        traceAfterExecute(jp);
    }

    @After("executeMethod")
    public void traceAfterExecute(JoinPoint jp) {
        Method method = ((MethodSignature) jp.getSignature()).getMethod();
        getTrace().traceAfterCall(method);
    }
}

==> isis-fish-4.3.0.0-sources.jar: fr/ifremer/isisfish/aspect/TraceAspect.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: TraceAspect.java 3969 2014-04-17 16:48:13Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2006 - 2011 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.aspect;

import java.lang.reflect.Method;

import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.After;
import org.aspectj.lang.annotation.AfterThrowing;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.reflect.MethodSignature;

import fr.ifremer.isisfish.simulator.SimulationContext;
import fr.ifremer.isisfish.util.Trace;

/**
 * Permet de tracer les appels aux methodes utilisateur ainsi que l'execution
 * a ces methodes. La difference entre les deux est lors de l'utilisation du
 * cache les appels seront superieur a l'execution car certaine valeur seront
 * reutilisé dans le cache
 * 
 * Created: 25 août 06 22:19:21
 *
 * @author poussin
 * @version $Revision: 3969 $
 *
 * Last update: $Date: 2014-04-17 18:48:13 +0200 (Thu, 17 Apr 2014) $
 * by : $Author: echatellier $
 */
@Aspect
public class TraceAspect {

    /*@Pointcut("execution(* scripts..*(..))"
            + " || execution(* simulators..*(..))"
            + " || execution(* rules..*(..)) "
            + " || execution(* simulationplans..*(..)) "
            + " || execution(* formules..*(..))")
    Pointcut executeMethod;*/

    public TraceAspect() {
    }

    /**
     * Return trace object from context.
     * 
     * @return trace object from context
     */
    protected Trace getTrace() {
        SimulationContext context = SimulationContext.get();
        Trace result = context.getTrace();
        return result;
    }

    @Before("execution(* scripts..*(..))"
            + " || execution(* simulators..*(..))"
            + " || execution(* rules..*(..)) "
            + " || execution(* simulationplans..*(..)) "
            + " || execution(* formules..*(..))")
    public void traceBeforeExecute(JoinPoint jp) {
        getTrace().traceBefore();
    }

    @AfterThrowing(throwing = "ex",
            pointcut = "execution(* scripts..*(..))"
            + " || execution(* simulators..*(..))"
            + " || execution(* rules..*(..)) "
            + " || execution(* simulationplans..*(..)) "
            + " || execution(* formules..*(..))")
    public void traceAfterThrowingExecute(JoinPoint jp, Exception ex) {
        // si une exeption est leve, il faut faire la meme chose
        traceAfterExecute(jp);
    }

    @After("execution(* scripts..*(..))"
            + " || execution(* simulators..*(..))"
            + " || execution(* rules..*(..)) "
            + " || execution(* simulationplans..*(..)) "
            + " || execution(* formules..*(..))")
    public void traceAfterExecute(JoinPoint jp) {
        Method method = ((MethodSignature) jp.getSignature()).getMethod();
        getTrace().traceAfterCall(method);
    }
}
